@@ -1,5 +1,5 @@
 import Py_FS.wrapper.nature_inspired
 
 __all__ = [
-    'nature_inspired'
+    "nature_inspired"
 ]
\ No newline at end of file
