@@ -12,9 +12,14 @@ import matplotlib.pyplot as plt
 from sklearn.model_selection import train_test_split
 from sklearn import datasets
 
-# from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
+import os, sys
+dir_path = os.path.dirname(os.path.realpath(__file__))
+sys.path.insert(0, dir_path)
 from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 
+# from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
+# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
+
 
 def GA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitness, prob_cross=0.4, prob_mut=0.3, save_conv_graph=False, seed=0):
 
@@ -58,7 +63,6 @@ def GA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitne
     # initialize convergence curves
     convergence_curve = {}
     convergence_curve['fitness'] = np.zeros(max_iter)
-    convergence_curve['feature_count'] = np.zeros(max_iter)
 
     # initialize data class
     data = Data()
@@ -94,10 +98,8 @@ def GA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitne
         if fitness[0]>Leader_fitness:
             Leader_agent = chromosomes[0].copy()
             Leader_fitness = fitness[0].copy()
-        # convergence_curve['fitness'][iter_no] = Leader_fitness
-        # convergence_curve['feature_count'][iter_no] = int(np.sum(Leader_agent))
+
         convergence_curve['fitness'][iter_no] = np.mean(fitness)
-        convergence_curve['feature_count'][iter_no] = np.mean(np.sum(chromosomes,axis=1))
 
     # compute final accuracy
     Leader_agent, Leader_accuracy = sort_agents(Leader_agent, compute_accuracy, data)
@@ -115,7 +117,7 @@ def GA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitne
     end_time = time.time()
     exec_time = end_time - start_time
 
-    # Plot
+    # plot convergence graph
     fig, axes = Conv_plot(convergence_curve)
     if(save_conv_graph):
         plt.savefig('convergence_graph_'+ short_name + '.jpg')
@@ -187,9 +189,7 @@ def cross_mut(chromosomes, fitness, obj, data, prob_cross, cross_limit, prob_mut
             child, child_fitness = sort_agents(child, obj, data)
 
             for i in range(2):
-                print(fitness[0])
                 for j in range(num_agents):
-                    print('i:', i, child_fitness[i], 'j:', j, fitness[j])
                     if(child_fitness[i] > fitness[j]):
                         print('child {} replaced with chromosome having id {}'.format(i+1, j+1))
                         chromosomes[j] = child[i]
@@ -210,6 +210,6 @@ def cross_mut(chromosomes, fitness, obj, data, prob_cross, cross_limit, prob_mut
 ############# for testing purpose ################
 
 if __name__ == '__main__':
-    iris = datasets.load_wine()
-    GA(20, 10, iris.data, iris.target, save_conv_graph=True)
+    data = datasets.load_digits()
+    GA(20, 100, data.data, data.target, save_conv_graph=True)
 ############# for testing purpose ################
