@@ -17,7 +17,7 @@ from sklearn import datasets
 
 from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 from Py_FS.wrapper.nature_inspired._transfer_functions import get_trans_function
-# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness
+# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 # from _transfer_functions import get_trans_function
 
 
@@ -60,7 +60,6 @@ def GWO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
     # initialize convergence curves
     convergence_curve = {}
     convergence_curve['fitness'] = np.zeros(max_iter)
-    convergence_curve['feature_count'] = np.zeros(max_iter)
 
     # initialize data class
     data = Data()
@@ -168,8 +167,7 @@ def GWO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
             Leader_agent = alpha.copy()
 
 
-        convergence_curve['fitness'][iter_no] = Leader_fitness
-        convergence_curve['feature_count'][iter_no] = int(np.sum(Leader_agent))
+        convergence_curve['fitness'][iter_no] = np.mean(fitness)
 
 
     # compute final accuracy
@@ -188,7 +186,7 @@ def GWO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
     end_time = time.time()
     exec_time = end_time - start_time
 
-    # Plot
+    # plot convergence graph
     fig, axes = Conv_plot(convergence_curve)
     if(save_conv_graph):
         plt.savefig('convergence_graph_'+ short_name + '.jpg')
@@ -209,5 +207,5 @@ def GWO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
 
 if __name__ == '__main__':
 
-    iris = datasets.load_iris()
-    GWO(10, 20, iris.data, iris.target, save_conv_graph=True)
+    data = datasets.load_digits()
+    GWO(20, 100, data.data, data.target, save_conv_graph=True)
