@@ -17,7 +17,7 @@ from sklearn import datasets
 
 from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 from Py_FS.wrapper.nature_inspired._transfer_functions import get_trans_function
-# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness
+# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 # from _transfer_functions import get_trans_function
 
 def MA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitness, trans_function_shape='s',  prob_mut=0.2,  save_conv_graph=False):
@@ -78,7 +78,6 @@ def MA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitne
     # initialize convergence curves
     convergence_curve = {}
     convergence_curve['fitness'] = np.zeros(max_iter)
-    convergence_curve['feature_count'] = np.zeros(max_iter)
     
     # initialize data class
     data = Data()
@@ -165,8 +164,8 @@ def MA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitne
         if(male_fitness[0] > Leader_fitness):
             Leader_agent = male_pos[0].copy()
             Leader_fitness = male_fitness[0].copy()
-        convergence_curve['fitness'][iter_no] = Leader_fitness
-        convergence_curve['feature_count'][iter_no] = int(np.sum(Leader_agent))
+
+        convergence_curve['fitness'][iter_no] = np.mean(male_fitness)
     
     # compute final accuracy
     Leader_agent, Leader_accuracy = sort_agents(Leader_agent, compute_accuracy, data)
@@ -184,7 +183,7 @@ def MA(num_agents, max_iter, train_data, train_label, obj_function=compute_fitne
     end_time = time.time()
     exec_time = end_time - start_time
     
-    # Plot
+    # plot convergence graph
     fig, axes = Conv_plot(convergence_curve)
     if(save_conv_graph):
         plt.savefig('convergence_graph_'+ short_name + '.jpg')
@@ -316,5 +315,5 @@ def compare_and_replace(pos, off, fit, data, obj):
 
 
 if __name__ == '__main__':
-    iris = datasets.load_iris()
-    MA(10, 20, iris.data, iris.target, save_conv_graph=True)
\ No newline at end of file
+    data = datasets.load_digits()
+    MA(20, 30, data.data, data.target, save_conv_graph=True)
\ No newline at end of file
