@@ -18,7 +18,7 @@ from sklearn import datasets
 
 from Py_FS.wrapper.nature_inspired._utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 from Py_FS.wrapper.nature_inspired._transfer_functions import get_trans_function
-# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness
+# from _utilities import Solution, Data, initialize, sort_agents, display, compute_fitness, Conv_plot
 # from _transfer_functions import get_trans_function
 
 
@@ -61,7 +61,6 @@ def PSO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
     # initialize convergence curves
     convergence_curve = {}
     convergence_curve['fitness'] = np.zeros(max_iter)
-    convergence_curve['feature_count'] = np.zeros(max_iter)
 
     # initialize data class
     data = Data()
@@ -134,8 +133,7 @@ def PSO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
             Leader_agent = globalBestParticle.copy()
             Leader_fitness = globalBestFitness.copy()
 
-        convergence_curve['fitness'][iter_no] = Leader_fitness
-        convergence_curve['feature_count'][iter_no] = int(np.sum(Leader_agent))
+        convergence_curve['fitness'][iter_no] = np.mean(fitness)
 
     # compute final accuracy
     Leader_agent, Leader_accuracy = sort_agents(Leader_agent, compute_accuracy, data)
@@ -153,7 +151,7 @@ def PSO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
     end_time = time.time()
     exec_time = end_time - start_time
 
-    # Plot
+    # plot convergence graph
     fig, axes = Conv_plot(convergence_curve)
     if(save_conv_graph):
         plt.savefig('convergence_graph_'+ short_name + '.jpg')
@@ -174,6 +172,6 @@ def PSO(num_agents, max_iter, train_data, train_label, obj_function=compute_fitn
 
 if __name__ == '__main__':
     
-    iris = datasets.load_iris()
-    PSO(10, 20, iris.data, iris.target, save_conv_graph=True)
+    data = datasets.load_digits()
+    PSO(20, 100, data.data, data.target, save_conv_graph=True)
 
