@@ -13,16 +13,16 @@ from Py_FS.wrapper.nature_inspired.WOA import WOA
 
 
 __all__ = [
-    'BBA',
-    'CS',
-    'EO',
-    'GA',
-    'GSA',
-    'GWO',
-    'HS',
-    'MA',
-    'PSO',
-    'RDA',
-    'SCA',
-    'WOA'
+    "BBA",
+    "CS",
+    "EO",
+    "GA",
+    "GSA",
+    "GWO",
+    "HS",
+    "MA",
+    "PSO",
+    "RDA",
+    "SCA",
+    "WOA"
 ]
\ No newline at end of file
